@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-
-# -*- coding: utf-8 -*-
 __title__ = 'createsend-python'
 __author__ = 'Campaign Monitor'
 __license__ = 'MIT'
